==> flutter_integration-0.0.5.tar.gz: ios/Classes/FlutterIntegrationManager.m <==
//
//  IGFlutterEngineManager.m
//  IGame
//
//  Created by junshao on 2019/12/15.
//  Copyright © 2019 Tencent. All rights reserved.
//

#import "FlutterIntegrationManager.h"

@implementation FlutterIntegrationManager

+(instancetype)sharedInstance{
    static FlutterIntegrationManager *instance;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        instance = [[FlutterIntegrationManager alloc] init];
    });
    return instance;
}

-(void)initEngine{
    FlutterEngine *flutterEngine = [[FlutterEngine alloc] initWithName:@"flutterEngine" project:nil];
    [flutterEngine runWithEntrypoint:nil];
    Class clazz = NSClassFromString(@"GeneratedPluginRegistrant");
    if (clazz) {
        if ([clazz respondsToSelector:NSSelectorFromString(@"registerWithRegistry:")]) {
            [clazz performSelector:NSSelectorFromString(@"registerWithRegistry:") withObject:flutterEngine];
        }
    }

    FlutterMethodChannel *methodChannel = [FlutterMethodChannel methodChannelWithName:@"flutter_integration"
                                  binaryMessenger:flutterEngine.binaryMessenger];

    FlutterIntegrationEngineContainer *container = [FlutterIntegrationEngineContainer new];
    container.flutterEngine = flutterEngine;
    container.flutterMethodChannel = methodChannel;

    self.flutterEngineContainer = container;
    
    self.dummyVC = [[FlutterViewController alloc] initWithEngine:flutterEngine nibName:nil bundle:nil];

    [self registerMethodCallHandler];
}

- (void)registerMethodCallHandler {
    [self.flutterEngineContainer.flutterMethodChannel setMethodCallHandler:^(FlutterMethodCall *call, FlutterResult result) {
        
    }];
}


@end

==> flutter_integration-0.0.10.tar.gz: ios/Classes/FlutterIntegrationManager.m <==
//
//  IGFlutterEngineManager.m
//  IGame
//
//  Created by junshao on 2019/12/15.
//  Copyright © 2019 Tencent. All rights reserved.
//

#import "FlutterIntegrationManager.h"
#import "FlutterIntegrationViewController.h"

@implementation FlutterIntegrationManager

+(instancetype)sharedInstance{
    static FlutterIntegrationManager *instance;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        instance = [[FlutterIntegrationManager alloc] init];
    });
    return instance;
}

-(void)initEngine{
    FlutterEngine *flutterEngine = [[FlutterEngine alloc] initWithName:@"flutterEngine" project:nil];
    [flutterEngine runWithEntrypoint:nil];
    Class clazz = NSClassFromString(@"GeneratedPluginRegistrant");
    if (clazz) {
        if ([clazz respondsToSelector:NSSelectorFromString(@"registerWithRegistry:")]) {
            [clazz performSelector:NSSelectorFromString(@"registerWithRegistry:") withObject:flutterEngine];
        }
    }

    FlutterMethodChannel *methodChannel = [FlutterMethodChannel methodChannelWithName:@"flutter_integration"
                                  binaryMessenger:flutterEngine.binaryMessenger];

    FlutterIntegrationEngineContainer *container = [FlutterIntegrationEngineContainer new];
    container.flutterEngine = flutterEngine;
    container.flutterMethodChannel = methodChannel;

    self.flutterEngineContainer = container;
    
    self.holderVC = [[FlutterIntegrationViewController alloc] initWithEngine:flutterEngine nibName:nil bundle:nil];

    [self registerMethodCallHandler];
}

- (void)registerMethodCallHandler {
    [self.flutterEngineContainer.flutterMethodChannel setMethodCallHandler:^(FlutterMethodCall *call, FlutterResult result) {
        
    }];
}


@end
